Statsig (statsig_elixir v0.20.2)
Summary
Functions
Returns a specification to start this module under a supervisor.
Returns the experiment's active state and the group name, rule id, id type, and return value for each of its groups, without requiring a user evaluation.
Callback implementation for GenServer.init/1.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec get_experiment_groups(String.t()) :: {:ok, Statsig.ExperimentGroupsResult.t()} | {:error, term()}
Returns the experiment's active state and the group name, rule id, id type, and return value for each of its groups, without requiring a user evaluation.
Returns {:ok, %Statsig.ExperimentGroupsResult{}} where is_experiment_active is
nil if the name does not refer to an experiment (unknown name or a non-experiment
entity like a dynamic config or autotune), and otherwise reflects the experiment's
isActive state; groups contains the experiment's groups regardless of that
state. Rules that are not experiment groups (e.g. holdout or sizing rules) are
excluded.
Callback implementation for GenServer.init/1.