A group within an experiment, exposing its name, rule id, id type, and return value without requiring a user evaluation.
@type t() :: %Statsig.ExperimentGroup{ group_name: String.t(), id_type: String.t(), return_value: %{optional(String.t()) => any()}, rule_id: String.t() }