Statsig.ExperimentGroupsResult (statsig_elixir v0.20.2)

The groups of an experiment along with its active state, exposed without requiring a user evaluation.

is_experiment_active is nil when the name does not refer to an experiment (unknown name or a non-experiment entity like a dynamic config or autotune); otherwise it reflects the experiment's isActive state.

Summary

Types

t()

@type t() :: %Statsig.ExperimentGroupsResult{
  groups: [Statsig.ExperimentGroup.t()],
  is_experiment_active: boolean() | nil
}